@@ -1,6 +1,24 @@
+/* 
+   Copyright (C) 2003-2008 FreeIPMI Core Team
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.  
+*/
+
 #if HAVE_CONFIG_H
 #include "config.h"
-#endif
+#endif /* HAVE_CONFIG_H */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -14,6 +32,10 @@
 #include "bmc-config-validate.h"
 #include "bmc-config-utils.h"
 
+#include "freeipmi-portability.h"
+#include "pstdout.h"
+#include "tool-fiid-wrappers.h"
+
 static config_err_t
 _rmcpplus_cipher_suite_id_privilege_setup(bmc_config_state_data_t *state_data)
 {
@@ -41,26 +63,26 @@ _rmcpplus_cipher_suite_id_privilege_setup(bmc_config_state_data_t *state_data)
 
   if (!state_data->cipher_suite_entry_count)
     {
-      if (!(obj_cmd_count_rs = Fiid_obj_create(tmpl_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_entry_support_rs)))
-	goto cleanup;
+      _FIID_OBJ_CREATE(obj_cmd_count_rs, tmpl_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_entry_support_rs);
 
-      if (ipmi_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_entry_support (state_data->dev, 
+      if (ipmi_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_entry_support (state_data->ipmi_ctx, 
 												   channel_number, 
 												   IPMI_GET_LAN_PARAMETER, 
 												   SET_SELECTOR, 
 												   BLOCK_SELECTOR, 
 												   obj_cmd_count_rs) < 0)
         {
-          if (state_data->prog_data->args->common.flags & IPMI_FLAGS_DEBUG_DUMP)
-            fprintf(stderr,
-                    "ipmi_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_entry_support: %s\n",
-                    ipmi_device_strerror(ipmi_device_errnum(state_data->dev)));
-          rv = CONFIG_ERR_NON_FATAL_ERROR;
+          if (state_data->prog_data->args->config_args.common.debug)
+            pstdout_fprintf(state_data->pstate,
+                            stderr,
+                            "ipmi_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_entry_support: %s\n",
+                            ipmi_ctx_strerror(ipmi_ctx_errnum(state_data->ipmi_ctx)));
+          if (!IPMI_CTX_ERRNUM_IS_FATAL_ERROR(state_data->ipmi_ctx))
+            rv = CONFIG_ERR_NON_FATAL_ERROR;
           goto cleanup;
         }
 
-      if (Fiid_obj_get (obj_cmd_count_rs, "cipher_suite_entry_count", &val) < 0)
-	goto cleanup;
+      _FIID_OBJ_GET (obj_cmd_count_rs, "cipher_suite_entry_count", &val);
 
       state_data->cipher_suite_entry_count = val;
 
@@ -70,21 +92,22 @@ _rmcpplus_cipher_suite_id_privilege_setup(bmc_config_state_data_t *state_data)
 
   if (!state_data->cipher_suite_id_supported_set)
     {
-      if (!(obj_cmd_id_rs = Fiid_obj_create(tmpl_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_entries_rs)))
-	goto cleanup;
+      _FIID_OBJ_CREATE(obj_cmd_id_rs, tmpl_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_entries_rs);
 
-      if (ipmi_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_entries (state_data->dev, 
+      if (ipmi_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_entries (state_data->ipmi_ctx, 
 											     channel_number, 
 											     IPMI_GET_LAN_PARAMETER, 
 											     SET_SELECTOR, 
 											     BLOCK_SELECTOR, 
 											     obj_cmd_id_rs) < 0)
         {
-          if (state_data->prog_data->args->common.flags & IPMI_FLAGS_DEBUG_DUMP)
-            fprintf(stderr,
-                    "ipmi_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_entries: %s\n",
-                    ipmi_device_strerror(ipmi_device_errnum(state_data->dev)));
-          rv = CONFIG_ERR_NON_FATAL_ERROR;
+          if (state_data->prog_data->args->config_args.common.debug)
+            pstdout_fprintf(state_data->pstate,
+                            stderr,
+                            "ipmi_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_entries: %s\n",
+                            ipmi_ctx_strerror(ipmi_ctx_errnum(state_data->ipmi_ctx)));
+          if (!IPMI_CTX_ERRNUM_IS_FATAL_ERROR(state_data->ipmi_ctx))
+            rv = CONFIG_ERR_NON_FATAL_ERROR;
           goto cleanup;
         }
 
@@ -125,8 +148,7 @@ _rmcpplus_cipher_suite_id_privilege_setup(bmc_config_state_data_t *state_data)
 	  else if (i == 15)
 	    field = "cipher_suite_id_entry_P";
 
-	  if (Fiid_obj_get (obj_cmd_id_rs, field, &val) < 0)
-	    goto cleanup;
+	  _FIID_OBJ_GET (obj_cmd_id_rs, field, &val);
 	  
 	  state_data->cipher_suite_id_supported[i] = val;
 	}
@@ -136,21 +158,22 @@ _rmcpplus_cipher_suite_id_privilege_setup(bmc_config_state_data_t *state_data)
   
   if (!state_data->cipher_suite_priv_set)
     {
-      if (!(obj_cmd_priv_rs = Fiid_obj_create(tmpl_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_privilege_levels_rs)))
-	goto cleanup;
+      _FIID_OBJ_CREATE(obj_cmd_priv_rs, tmpl_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_privilege_levels_rs);
 
-      if (ipmi_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_privilege_levels (state_data->dev, 
+      if (ipmi_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_privilege_levels (state_data->ipmi_ctx, 
 												      channel_number, 
 												      IPMI_GET_LAN_PARAMETER, 
 												      SET_SELECTOR, 
 												      BLOCK_SELECTOR, 
 												      obj_cmd_priv_rs) < 0)
         {
-          if (state_data->prog_data->args->common.flags & IPMI_FLAGS_DEBUG_DUMP)
-            fprintf(stderr,
-                    "ipmi_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_privilege_level: %s\n",
-                    ipmi_device_strerror(ipmi_device_errnum(state_data->dev)));
-          rv = CONFIG_ERR_NON_FATAL_ERROR;
+          if (state_data->prog_data->args->config_args.common.debug)
+            pstdout_fprintf(state_data->pstate,
+                            stderr,
+                            "ipmi_cmd_get_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_privilege_level: %s\n",
+                            ipmi_ctx_strerror(ipmi_ctx_errnum(state_data->ipmi_ctx)));
+          if (!IPMI_CTX_ERRNUM_IS_FATAL_ERROR(state_data->ipmi_ctx))
+            rv = CONFIG_ERR_NON_FATAL_ERROR;
           goto cleanup;
         }
 
@@ -191,8 +214,7 @@ _rmcpplus_cipher_suite_id_privilege_setup(bmc_config_state_data_t *state_data)
 	  else if (i == 15)
 	    field = "maximum_privilege_for_cipher_suite_16";
 
-	  if (Fiid_obj_get (obj_cmd_priv_rs, field, &val) < 0)
-	    goto cleanup;
+	  _FIID_OBJ_GET (obj_cmd_priv_rs, field, &val);
 	  
 	  state_data->cipher_suite_priv[i] = val;
 	}
@@ -202,9 +224,9 @@ _rmcpplus_cipher_suite_id_privilege_setup(bmc_config_state_data_t *state_data)
 
   rv = CONFIG_ERR_SUCCESS;
  cleanup:
-  Fiid_obj_destroy(obj_cmd_count_rs);
-  Fiid_obj_destroy(obj_cmd_id_rs);
-  Fiid_obj_destroy(obj_cmd_priv_rs);
+  _FIID_OBJ_DESTROY(obj_cmd_count_rs);
+  _FIID_OBJ_DESTROY(obj_cmd_id_rs);
+  _FIID_OBJ_DESTROY(obj_cmd_priv_rs);
   return (rv);
 }
 
@@ -234,7 +256,9 @@ id_checkout (const char *section_name,
   
   if (id_found)
     {
-      if (config_section_update_keyvalue_output(kv, rmcpplus_priv_string (privilege)) < 0)
+      if (config_section_update_keyvalue_output(state_data->pstate,
+                                                kv, 
+                                                rmcpplus_priv_string (privilege)) < 0)
         return CONFIG_ERR_FATAL_ERROR;
       return CONFIG_ERR_SUCCESS;
     }
@@ -258,8 +282,7 @@ id_commit (const char *section_name,
   if ((ret = _rmcpplus_cipher_suite_id_privilege_setup(state_data)) != CONFIG_ERR_SUCCESS)
     return ret;
 
-  if (!(obj_cmd_rs = Fiid_obj_create(tmpl_cmd_set_lan_configuration_parameters_rs)))
-    goto cleanup;
+  _FIID_OBJ_CREATE(obj_cmd_rs, tmpl_cmd_set_lan_configuration_parameters_rs);
 
   if ((ret = get_lan_channel_number (state_data, &channel_number)) != CONFIG_ERR_SUCCESS)
     {
@@ -273,7 +296,7 @@ id_commit (const char *section_name,
   memcpy(privs, state_data->cipher_suite_priv, CIPHER_SUITE_LEN);
   privs[id] = privilege;
   
-  if (ipmi_cmd_set_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_privilege_levels(state_data->dev,
+  if (ipmi_cmd_set_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_privilege_levels(state_data->ipmi_ctx,
                                                                                                  channel_number,
                                                                                                  privs[0],
                                                                                                  privs[1],
@@ -293,11 +316,13 @@ id_commit (const char *section_name,
                                                                                                  privs[15],
                                                                                                  obj_cmd_rs) < 0)
     {
-      if (state_data->prog_data->args->common.flags & IPMI_FLAGS_DEBUG_DUMP)
-        fprintf(stderr,
-                "ipmi_cmd_set_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_privilege_levels: %s\n",
-                ipmi_device_strerror(ipmi_device_errnum(state_data->dev)));
-      rv = CONFIG_ERR_NON_FATAL_ERROR;
+      if (state_data->prog_data->args->config_args.common.debug)
+        pstdout_fprintf(state_data->pstate,
+                        stderr,
+                        "ipmi_cmd_set_lan_configuration_parameters_rmcpplus_messaging_cipher_suite_privilege_levels: %s\n",
+                        ipmi_ctx_strerror(ipmi_ctx_errnum(state_data->ipmi_ctx)));
+      if (!IPMI_CTX_ERRNUM_IS_FATAL_ERROR(state_data->ipmi_ctx))
+        rv = CONFIG_ERR_NON_FATAL_ERROR;
       goto cleanup;
     }
       
@@ -305,7 +330,7 @@ id_commit (const char *section_name,
   rv = CONFIG_ERR_SUCCESS;
   
  cleanup:
-  Fiid_obj_destroy(obj_cmd_rs);
+  _FIID_OBJ_DESTROY(obj_cmd_rs);
   return (rv);
 }
 
@@ -342,13 +367,17 @@ bmc_config_rmcpplus_conf_privilege_section_get (bmc_config_state_data_t *state_d
     "username configured should set for support under a cipher suite ID. "
     "This is typically \"Administrator\".";
 
-  if (!(rmcpplus_conf_privilege_section = config_section_create ("Rmcpplus_Conf_Privilege",
+  if (!(rmcpplus_conf_privilege_section = config_section_create (state_data->pstate,
+                                                                 "Rmcpplus_Conf_Privilege",
                                                                  "Rmcpplus_Conf_Privilege",
                                                                  section_comment,
-                                                                 0)))
+                                                                 0,
+                                                                 NULL,
+                                                                 NULL)))
     goto cleanup;
 
-  if (config_section_add_key (rmcpplus_conf_privilege_section,
+  if (config_section_add_key (state_data->pstate,
+                              rmcpplus_conf_privilege_section,
                               "Maximum_Privilege_Cipher_Suite_Id_0",
                               "Possible values: Unused/User/Operator/Administrator/OEM_Proprietary",
                               0,
@@ -357,7 +386,8 @@ bmc_config_rmcpplus_conf_privilege_section_get (bmc_config_state_data_t *state_d
                               rmcpplus_priv_number_validate) < 0)
     goto cleanup;
 
-  if (config_section_add_key (rmcpplus_conf_privilege_section,
+  if (config_section_add_key (state_data->pstate,
+                              rmcpplus_conf_privilege_section,
                               "Maximum_Privilege_Cipher_Suite_Id_1",
                               "Possible values: Unused/User/Operator/Administrator/OEM_Proprietary",
                               0,
@@ -366,7 +396,8 @@ bmc_config_rmcpplus_conf_privilege_section_get (bmc_config_state_data_t *state_d
                               rmcpplus_priv_number_validate) < 0)
     goto cleanup;
 
-  if (config_section_add_key (rmcpplus_conf_privilege_section,
+  if (config_section_add_key (state_data->pstate,
+                              rmcpplus_conf_privilege_section,
                               "Maximum_Privilege_Cipher_Suite_Id_2",
                               "Possible values: Unused/User/Operator/Administrator/OEM_Proprietary",
                               0,
@@ -375,7 +406,8 @@ bmc_config_rmcpplus_conf_privilege_section_get (bmc_config_state_data_t *state_d
                               rmcpplus_priv_number_validate) < 0)
     goto cleanup;
 
-  if (config_section_add_key (rmcpplus_conf_privilege_section,
+  if (config_section_add_key (state_data->pstate,
+                              rmcpplus_conf_privilege_section,
                               "Maximum_Privilege_Cipher_Suite_Id_3",
                               "Possible values: Unused/User/Operator/Administrator/OEM_Proprietary",
                               0,
@@ -384,7 +416,8 @@ bmc_config_rmcpplus_conf_privilege_section_get (bmc_config_state_data_t *state_d
                               rmcpplus_priv_number_validate) < 0)
     goto cleanup;
 
-  if (config_section_add_key (rmcpplus_conf_privilege_section,
+  if (config_section_add_key (state_data->pstate,
+                              rmcpplus_conf_privilege_section,
                               "Maximum_Privilege_Cipher_Suite_Id_4",
                               "Possible values: Unused/User/Operator/Administrator/OEM_Proprietary",
                               0,
@@ -393,7 +426,8 @@ bmc_config_rmcpplus_conf_privilege_section_get (bmc_config_state_data_t *state_d
                               rmcpplus_priv_number_validate) < 0)
     goto cleanup;
 
-  if (config_section_add_key (rmcpplus_conf_privilege_section,
+  if (config_section_add_key (state_data->pstate,
+                              rmcpplus_conf_privilege_section,
                               "Maximum_Privilege_Cipher_Suite_Id_5",
                               "Possible values: Unused/User/Operator/Administrator/OEM_Proprietary",
                               0,
@@ -402,7 +436,8 @@ bmc_config_rmcpplus_conf_privilege_section_get (bmc_config_state_data_t *state_d
                               rmcpplus_priv_number_validate) < 0)
     goto cleanup;
 
-  if (config_section_add_key (rmcpplus_conf_privilege_section,
+  if (config_section_add_key (state_data->pstate,
+                              rmcpplus_conf_privilege_section,
                               "Maximum_Privilege_Cipher_Suite_Id_6",
                               "Possible values: Unused/User/Operator/Administrator/OEM_Proprietary",
                               0,
@@ -411,7 +446,8 @@ bmc_config_rmcpplus_conf_privilege_section_get (bmc_config_state_data_t *state_d
                               rmcpplus_priv_number_validate) < 0)
     goto cleanup;
 
-  if (config_section_add_key (rmcpplus_conf_privilege_section,
+  if (config_section_add_key (state_data->pstate,
+                              rmcpplus_conf_privilege_section,
                               "Maximum_Privilege_Cipher_Suite_Id_7",
                               "Possible values: Unused/User/Operator/Administrator/OEM_Proprietary",
                               0,
@@ -420,7 +456,8 @@ bmc_config_rmcpplus_conf_privilege_section_get (bmc_config_state_data_t *state_d
                               rmcpplus_priv_number_validate) < 0)
     goto cleanup;
 
-  if (config_section_add_key (rmcpplus_conf_privilege_section,
+  if (config_section_add_key (state_data->pstate,
+                              rmcpplus_conf_privilege_section,
                               "Maximum_Privilege_Cipher_Suite_Id_8",
                               "Possible values: Unused/User/Operator/Administrator/OEM_Proprietary",
                               0,
@@ -429,7 +466,8 @@ bmc_config_rmcpplus_conf_privilege_section_get (bmc_config_state_data_t *state_d
                               rmcpplus_priv_number_validate) < 0)
     goto cleanup;
 
-  if (config_section_add_key (rmcpplus_conf_privilege_section,
+  if (config_section_add_key (state_data->pstate,
+                              rmcpplus_conf_privilege_section,
                               "Maximum_Privilege_Cipher_Suite_Id_9",
                               "Possible values: Unused/User/Operator/Administrator/OEM_Proprietary",
                               0,
@@ -438,7 +476,8 @@ bmc_config_rmcpplus_conf_privilege_section_get (bmc_config_state_data_t *state_d
                               rmcpplus_priv_number_validate) < 0)
     goto cleanup;
 
-  if (config_section_add_key (rmcpplus_conf_privilege_section,
+  if (config_section_add_key (state_data->pstate,
+                              rmcpplus_conf_privilege_section,
                               "Maximum_Privilege_Cipher_Suite_Id_10",
                               "Possible values: Unused/User/Operator/Administrator/OEM_Proprietary",
                               0,
@@ -447,7 +486,8 @@ bmc_config_rmcpplus_conf_privilege_section_get (bmc_config_state_data_t *state_d
                               rmcpplus_priv_number_validate) < 0)
     goto cleanup;
 
-  if (config_section_add_key (rmcpplus_conf_privilege_section,
+  if (config_section_add_key (state_data->pstate,
+                              rmcpplus_conf_privilege_section,
                               "Maximum_Privilege_Cipher_Suite_Id_11",
                               "Possible values: Unused/User/Operator/Administrator/OEM_Proprietary",
                               0,
@@ -456,7 +496,8 @@ bmc_config_rmcpplus_conf_privilege_section_get (bmc_config_state_data_t *state_d
                               rmcpplus_priv_number_validate) < 0)
     goto cleanup;
 
-  if (config_section_add_key (rmcpplus_conf_privilege_section,
+  if (config_section_add_key (state_data->pstate,
+                              rmcpplus_conf_privilege_section,
                               "Maximum_Privilege_Cipher_Suite_Id_12",
                               "Possible values: Unused/User/Operator/Administrator/OEM_Proprietary",
                               0,
@@ -465,7 +506,8 @@ bmc_config_rmcpplus_conf_privilege_section_get (bmc_config_state_data_t *state_d
                               rmcpplus_priv_number_validate) < 0)
     goto cleanup;
 
-  if (config_section_add_key (rmcpplus_conf_privilege_section,
+  if (config_section_add_key (state_data->pstate,
+                              rmcpplus_conf_privilege_section,
                               "Maximum_Privilege_Cipher_Suite_Id_13",
                               "Possible values: Unused/User/Operator/Administrator/OEM_Proprietary",
                               0,
@@ -474,7 +516,8 @@ bmc_config_rmcpplus_conf_privilege_section_get (bmc_config_state_data_t *state_d
                               rmcpplus_priv_number_validate) < 0)
     goto cleanup;
 
-  if (config_section_add_key (rmcpplus_conf_privilege_section,
+  if (config_section_add_key (state_data->pstate,
+                              rmcpplus_conf_privilege_section,
                               "Maximum_Privilege_Cipher_Suite_Id_14",
                               "Possible values: Unused/User/Operator/Administrator/OEM_Proprietary",
                               0,
@@ -487,7 +530,7 @@ bmc_config_rmcpplus_conf_privilege_section_get (bmc_config_state_data_t *state_d
 
  cleanup:
   if (rmcpplus_conf_privilege_section)
-    config_section_destroy(rmcpplus_conf_privilege_section);
+    config_section_destroy(state_data->pstate, rmcpplus_conf_privilege_section);
   return NULL;
 }
 
