@@ -1,9 +1,5 @@
 /* 
-   $Id: ipmi-locate-argp.c,v 1.6 2007/09/05 20:13:26 chu11 Exp $ 
-   
-   ipmi-locate-argp.c - command line argument parser.
-   
-   Copyright (C) 2005 FreeIPMI Core Team
+   Copyright (C) 2005-2008 FreeIPMI Core Team
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -22,35 +18,48 @@
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
+#endif /* HAVE_CONFIG_H */
 
+#include <stdio.h>
+#include <stdlib.h>
+#if HAVE_ARGP_H
 #include <argp.h>
+#else /* !HAVE_ARGP_H */
+#include "freeipmi-argp.h"
+#endif /* !HAVE_ARGP_H */
 
 #include "ipmi-locate-argp.h"
 
-static error_t parse_opt (int key, char *arg, struct argp_state *state);
+#include "freeipmi-portability.h"
 
 const char *argp_program_version = 
-"IPMI Locate [ipmi-locate-" PACKAGE_VERSION "]\n"
-"Copyright (C) 2003-2005 FreeIPMI Core Team\n"
-"This program is free software; you may redistribute it under the terms of\n"
-"the GNU General Public License.  This program has absolutely no warranty.";
+  "ipmi-locate - " PACKAGE_VERSION "\n"
+  "Copyright (C) 2003-2008 FreeIPMI Core Team\n"
+  "This program is free software; you may redistribute it under the terms of\n"
+  "the GNU General Public License.  This program has absolutely no warranty.";
 
-const char *argp_program_bug_address = "<freeipmi-devel@gnu.org>";
+const char *argp_program_bug_address = 
+  "<" PACKAGE_BUGREPORT ">";
 
-static char doc[] = "IPMI Locate - Probes and displays IPMI devices.";
+static char cmdline_doc[] = 
+  "ipmi-locate - IPMI probing utility";
 
-static char args_doc[] = "";
+static char cmdline_args_doc[] = "";
 
-static struct argp_option options[] = 
+static struct argp_option cmdline_options[] = 
   {
     { 0 }
   };
 
-static struct argp argp = { options, parse_opt, args_doc, doc };
+static error_t cmdline_parse (int key, char *arg, struct argp_state *state);
+
+static struct argp cmdline_argp = { cmdline_options,
+                                    cmdline_parse,
+                                    cmdline_args_doc,
+                                    cmdline_doc };
 
 static error_t 
-parse_opt (int key, char *arg, struct argp_state *state)
+cmdline_parse (int key, char *arg, struct argp_state *state)
 {
   switch (key)
     {
@@ -70,6 +79,6 @@ parse_opt (int key, char *arg, struct argp_state *state)
 void 
 ipmi_locate_argp_parse (int argc, char **argv)
 {
-  argp_parse (&argp, argc, argv, ARGP_IN_ORDER, NULL, NULL);
+  argp_parse (&cmdline_argp, argc, argv, ARGP_IN_ORDER, NULL, NULL);
 }
 
