@@ -30,4 +30,8 @@ int ipmi_oem_inventec_set_mac_address (ipmi_oem_state_data_t *state_data);
 int ipmi_oem_inventec_get_bmc_services (ipmi_oem_state_data_t *state_data);
 int ipmi_oem_inventec_set_bmc_services (ipmi_oem_state_data_t *state_data);
 
+int ipmi_oem_inventec_read_eeprom (ipmi_oem_state_data_t *state_data);
+
+int ipmi_oem_inventec_clear_eeprom (ipmi_oem_state_data_t *state_data);
+
 #endif
