@@ -959,6 +959,18 @@ _parse_sel_record (ipmi_sel_state_data_t *state_data,
   _FIID_OBJ_GET (obj, "record_type", &val);
   record_type = val;
 
+  /* IPMI Workaround
+   *
+   * HP DL 380 G5
+   *
+   * Motherboard is reporting SEL Records of record type 0x00, which
+   * is not a valid record type.
+   */
+  if (state_data->prog_data->args->assume_system_event_records
+      && (record_type == 0x00
+          || record_type == 0x01))
+    record_type = 0x02;
+
   switch (_get_sel_record_type (record_type))
     {
     case SEL_RECORD_TYPE_SYSTEM_EVENT_RECORD:
