@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: ipmiconsole_checks.c,v 1.20 2007/10/18 16:18:46 chu11 Exp $
+ *  $Id: ipmiconsole_checks.c,v 1.22.10.1 2008/12/12 18:55:51 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2006-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -49,6 +49,8 @@
 #include "ipmiconsole_fiid_wrappers.h"
 #include "ipmiconsole_packet.h"
 
+#include "freeipmi-portability.h"
+
 int
 ipmiconsole_check_checksum(ipmiconsole_ctx_t c, ipmiconsole_packet_type_t p)
 {
@@ -923,6 +925,9 @@ ipmiconsole_check_integrity_pad(ipmiconsole_ctx_t c, ipmiconsole_packet_type_t p
 	 || p == IPMICONSOLE_PACKET_TYPE_DEACTIVATE_PAYLOAD_RS
 	 || p == IPMICONSOLE_PACKET_TYPE_CLOSE_SESSION_RS);
 
+  if (c->config.integrity_algorithm == IPMI_INTEGRITY_ALGORITHM_NONE)
+    return 1;
+
   if ((rv = ipmi_rmcpplus_check_integrity_pad(c->connection.obj_rmcpplus_session_trlr_rs)) < 0)
 
     IPMICONSOLE_CTX_DEBUG(c, ("ipmi_rmcpplus_check_integrity_pad: p = %d; %s", p, strerror(errno)));
