@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: ipmidetect.c,v 1.7 2007/10/18 16:18:48 chu11 Exp $
+ *  $Id: ipmidetect.c,v 1.12 2008/08/12 18:14:38 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -35,20 +35,19 @@
 #include <stdarg.h>
 #endif /* STDC_HEADERS */
 
-#define _GNU_SOURCE
 #if HAVE_GETOPT_H
 #include <getopt.h>
 #endif /* HAVE_GETOPT_H */
 #include <dirent.h>
 #if TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
+#include <sys/time.h>
+#include <time.h>
 #else  /* !TIME_WITH_SYS_TIME */
-# if HAVE_SYS_TIME_H
-#  include <sys/time.h>
-# else /* !HAVE_SYS_TIME_H */
-#  include <time.h>
-# endif /* !HAVE_SYS_TIME_H */
+#if HAVE_SYS_TIME_H
+#include <sys/time.h>
+#else /* !HAVE_SYS_TIME_H */
+#include <time.h>
+#endif  /* !HAVE_SYS_TIME_H */
 #endif /* !TIME_WITH_SYS_TIME */
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -59,9 +58,11 @@
 #include <errno.h>
 
 #include "ipmidetect.h"
-#include "hostlist.h"
+
+#include "freeipmi-portability.h"
 #include "error.h"
 #include "fd.h"
+#include "hostlist.h"
 
 /* 
  * External variables for getopt 
