@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: ipmipower_output.h,v 1.10 2007/10/18 16:18:52 chu11 Exp $
+ *  $Id: ipmipower_output.h,v 1.12 2008/05/17 16:12:36 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2003-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -32,7 +32,7 @@
 /* ipmipower_output
  * - Output msg with hostname prefix to ttyout
  */
-void ipmipower_output(msg_type_t num, char *hostname); 
+void ipmipower_output(msg_type_t num, const char *hostname); 
 
 /* ipmipower_output_finish
  * - Output final results
