@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: ipmipower_ping.c,v 1.21 2007/10/18 16:18:52 chu11 Exp $
+ *  $Id: ipmipower_ping.c,v 1.39 2008/08/12 18:14:41 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2003-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -40,8 +40,12 @@
 #include "ipmipower_util.h"
 #include "ipmipower_wrappers.h"
 
-extern struct ipmipower_config *conf;
+#include "freeipmi-portability.h"
+#include "debug-util.h"
+
+extern struct ipmipower_arguments cmd_args;
 extern struct ipmipower_connection *ics;
+extern unsigned int ics_len;
 
 /* next_ping_sends_time, when the next round of pings should be sent */
 static struct timeval next_ping_sends_time;
@@ -62,26 +66,26 @@ ipmipower_ping_process_pings(int *timeout)
   struct timeval cur_time, result;
   unsigned int ms_time;
     
-  assert(timeout != NULL);
+  assert(timeout);
 
-  if (conf->hosts == NULL)
+  if (!cmd_args.common.hostname)
     return;
 
-  if (!conf->ping_interval_len)
+  if (!cmd_args.ping_interval)
     return;
 
   Gettimeofday(&cur_time, NULL);
   if (timeval_gt(&cur_time, &next_ping_sends_time) || force_discovery_sweep) 
     {
       force_discovery_sweep = 0;
-      timeval_add_ms(&cur_time, conf->ping_interval_len, &next_ping_sends_time);
+      timeval_add_ms(&cur_time, cmd_args.ping_interval, &next_ping_sends_time);
       send_pings_flag++;
     }
 
-  for (i = 0; i < conf->hosts_count; i++) 
+  for (i = 0; i < ics_len; i++) 
     {
       int len;
-      char buffer[RMCP_PACKET_BUFLEN];
+      char buffer[IPMIPOWER_PACKET_BUFLEN];
       
       if (send_pings_flag) 
         {
@@ -89,14 +93,14 @@ ipmipower_ping_process_pings(int *timeout)
           fiid_obj_t rmcp_ping = NULL;
           int len;
           
-          memset(buffer, '\0', RMCP_PACKET_BUFLEN);
+          memset(buffer, '\0', IPMIPOWER_PACKET_BUFLEN);
 
           /* deal with packet heuristics */
-          if (conf->ping_packet_count && conf->ping_percent) 
+          if (cmd_args.ping_packet_count && cmd_args.ping_percent) 
             {
-              if (ics[i].ping_packet_count_send == conf->ping_packet_count) 
+              if (ics[i].ping_packet_count_send == cmd_args.ping_packet_count) 
                 {
-                  if ((((double)(ics[i].ping_packet_count_send - ics[i].ping_packet_count_recv))/ics[i].ping_packet_count_send) > ((double)conf->ping_percent/100))
+                  if ((((double)(ics[i].ping_packet_count_send - ics[i].ping_packet_count_recv))/ics[i].ping_packet_count_send) > ((double)cmd_args.ping_percent/100))
                     ics[i].link_state = LINK_BAD;
                   else
                     ics[i].link_state = LINK_GOOD;
@@ -106,9 +110,9 @@ ipmipower_ping_process_pings(int *timeout)
                 }
             }
             
-          if (conf->ping_consec_count) 
+          if (cmd_args.ping_consec_count) 
             {
-              if (ics[i].ping_last_packet_recv_flag == 0)
+              if (!ics[i].ping_last_packet_recv_flag)
                 ics[i].ping_consec_count = 0;
               ics[i].ping_last_packet_recv_flag = 0;
             }
@@ -122,32 +126,38 @@ ipmipower_ping_process_pings(int *timeout)
 	  rmcp_ping = Fiid_obj_create(tmpl_cmd_asf_presence_ping);
           
           if (fill_rmcp_hdr_asf(rmcp_hdr) < 0)
-            err_exit("fill_rmcp_hdr_asf: %s", strerror(errno));
+            ierr_exit("fill_rmcp_hdr_asf: %s", strerror(errno));
 
           if (fill_cmd_asf_presence_ping((ics[i].ping_sequence_number_counter % 
                                           (RMCP_ASF_MESSAGE_TAG_MAX + 1)), 
                                          rmcp_ping) < 0)
-            err_exit("fill_cmd_asf_presence_ping: %s", strerror(errno));
+            ierr_exit("fill_cmd_asf_presence_ping: %s", strerror(errno));
             
           if ((len = assemble_rmcp_pkt(rmcp_hdr,
 				       rmcp_ping, 
                                        (uint8_t *)buffer, 
-				       RMCP_PACKET_BUFLEN)) < 0)
-            err_exit("assemble_rmcp_pkt: %s", strerror(errno));
+				       IPMIPOWER_PACKET_BUFLEN)) < 0)
+            ierr_exit("assemble_rmcp_pkt: %s", strerror(errno));
           
 #ifndef NDEBUG
-          if (conf->rmcpdump) 
+          if (cmd_args.rmcpdump) 
             {
-              char *hdr = 
-                "============================================\n"
-                "= RMCP Ping                                =\n"
-                "============================================";
-              Ipmi_dump_rmcp_packet(STDERR_FILENO, 
-                                    ics[i].hostname, 
-                                    hdr, 
-                                    (uint8_t *)buffer, 
-                                    (uint32_t)len, 
-                                    tmpl_cmd_asf_presence_ping);
+              char hdrbuf[DEBUG_UTIL_HDR_BUFLEN];
+
+              debug_hdr_str(DEBUG_UTIL_TYPE_NONE,
+                            DEBUG_UTIL_DIRECTION_NONE,
+                            DEBUG_UTIL_RMCPPING_STR,
+                            hdrbuf,
+                            DEBUG_UTIL_HDR_BUFLEN);
+
+              if (ipmi_dump_rmcp_packet(STDERR_FILENO, 
+                                        ics[i].hostname,
+                                        hdrbuf, 
+                                        NULL,
+                                        (uint8_t *)buffer, 
+                                        (uint32_t)len, 
+                                        tmpl_cmd_asf_presence_ping) < 0)
+                ierr_dbg("ipmi_dump_rmcp_packet: %s", strerror(errno));
             }
 #endif /* NDEBUG */
 
@@ -156,7 +166,7 @@ ipmipower_ping_process_pings(int *timeout)
             ics[i].last_ping_send.tv_sec = cur_time.tv_sec;
             ics[i].last_ping_send.tv_usec = cur_time.tv_usec;
             
-            if (conf->ping_packet_count && conf->ping_percent)
+            if (cmd_args.ping_packet_count && cmd_args.ping_percent)
               ics[i].ping_packet_count_send++;
             
             Fiid_obj_destroy(rmcp_hdr);
@@ -164,8 +174,8 @@ ipmipower_ping_process_pings(int *timeout)
         }
       
       /* Did we receive something? */
-      memset(buffer, '\0', RMCP_PACKET_BUFLEN);
-      len = Cbuf_peek_and_drop(ics[i].ping_in, buffer, RMCP_PACKET_BUFLEN);
+      memset(buffer, '\0', IPMIPOWER_PACKET_BUFLEN);
+      len = Cbuf_peek_and_drop(ics[i].ping_in, buffer, IPMIPOWER_PACKET_BUFLEN);
       if (len > 0) 
         {
           fiid_obj_t rmcp_hdr = NULL;
@@ -176,26 +186,32 @@ ipmipower_ping_process_pings(int *timeout)
           rmcp_pong = Fiid_obj_create(tmpl_cmd_asf_presence_pong);
             
 #ifndef NDEBUG
-          if (conf->rmcpdump) 
+          if (cmd_args.rmcpdump) 
             {
-              char *hdr = 
-                "============================================\n"
-                "= RMCP Pong                                =\n"
-                "============================================";
-              Ipmi_dump_rmcp_packet(STDERR_FILENO, 
-                                    ics[i].hostname, 
-                                    hdr, 
-                                    (uint8_t *)buffer, 
-                                    (uint32_t)len, 
-                                    tmpl_cmd_asf_presence_pong);
+              char hdrbuf[DEBUG_UTIL_HDR_BUFLEN];
+
+              debug_hdr_str(DEBUG_UTIL_TYPE_NONE,
+                            DEBUG_UTIL_DIRECTION_NONE,
+                            DEBUG_UTIL_RMCPPING_STR,
+                            hdrbuf,
+                            DEBUG_UTIL_HDR_BUFLEN);
+
+              if (ipmi_dump_rmcp_packet(STDERR_FILENO, 
+                                        ics[i].hostname,
+                                        hdrbuf, 
+                                        NULL,
+                                        (uint8_t *)buffer, 
+                                        (uint32_t)len, 
+                                        tmpl_cmd_asf_presence_pong) < 0)
+                ierr_dbg("ipmi_dump_rmcp_packet: %s", strerror(errno));
             }
 #endif /* NDEBUG */
 
-          if (unassemble_rmcp_pkt(buffer, 
+          if (unassemble_rmcp_pkt((uint8_t *)buffer, 
 				  len, 
                                   rmcp_hdr, 
 				  rmcp_pong) < 0)
-            err_exit("unassemble_rmcp_pkt: %s", strerror(errno));
+            ierr_exit("unassemble_rmcp_pkt: %s", strerror(errno));
           
           /* achu: check for ipmi_support and pong type, but don't
            * check for message tag.  On occassion, I have witnessed
@@ -213,29 +229,29 @@ ipmipower_ping_process_pings(int *timeout)
                       
           if (message_type == RMCP_ASF_MESSAGE_TYPE_PRESENCE_PONG && ipmi_supported) 
             {
-              if (conf->ping_packet_count && conf->ping_percent)
+              if (cmd_args.ping_packet_count && cmd_args.ping_percent)
                 ics[i].ping_packet_count_recv++;
               
-              if (conf->ping_consec_count) 
+              if (cmd_args.ping_consec_count) 
                 {
                   /* Don't increment twice, its possible a previous pong
                    * response was late, and we quickly receive two
                    * pong responses
                    */
-                  if (ics[i].ping_last_packet_recv_flag == 0)
+                  if (!ics[i].ping_last_packet_recv_flag)
                     ics[i].ping_consec_count++;
                   
                   ics[i].ping_last_packet_recv_flag++;
                 }
               
-              if (conf->ping_packet_count && conf->ping_percent) 
+              if (cmd_args.ping_packet_count && cmd_args.ping_percent) 
                 {
                   if (ics[i].link_state == LINK_GOOD)
                     ics[i].discover_state = STATE_DISCOVERED;
                   else 
                     {
-                      if (conf->ping_consec_count
-                          && ics[i].ping_consec_count >= conf->ping_consec_count)
+                      if (cmd_args.ping_consec_count
+                          && ics[i].ping_consec_count >= cmd_args.ping_consec_count)
                         ics[i].discover_state = STATE_DISCOVERED;
                       else
                         ics[i].discover_state = STATE_BADCONNECTION;
@@ -256,7 +272,7 @@ ipmipower_ping_process_pings(int *timeout)
       /* Is the node gone?? */
       timeval_sub(&cur_time, &ics[i].last_ping_recv, &result);
       timeval_millisecond_calc(&result, &ms_time);
-      if (ms_time >= conf->ping_timeout_len)
+      if (ms_time >= cmd_args.ping_timeout)
         ics[i].discover_state = STATE_UNDISCOVERED;
     }
 
